package domain;

import junit.framework.*;

public class CardTest extends TestCase {
   public void testCreate() {
      Card card = new Card(Rank.ace, Suit.clubs);
      assertEquals(Rank.ace, card.getRank());
      assertEquals(Suit.clubs, card.getSuit());
   }

   public void testEquality() {
      Card card1 = new Card(Rank.king, Suit.hearts);
      Card card1copy = new Card(Rank.king, Suit.hearts);
      Card card1copy2 = new Card(Rank.king, Suit.hearts);
      Card card2 = new Card(Rank.queen, Suit.hearts);
      Card card3 = new Card(Rank.king, Suit.diamonds);
      assertTrue(card1.equals(card1copy));
      assertFalse(card1.equals(card2));
      assertFalse(card1.equals(card3));
      Card card1subtype = new Card(Rank.king, Suit.hearts) {};
      assertFalse(card1.equals(card1subtype));

      assertReflexivity(card1);
      assertSymmetry(card1, card1copy);
      assertTransitivity(card1, card1copy, card1copy2);
      assertConsistency(card1, card1copy, card2);
      assertNullComparison(card1);
   }
   
   private void assertNullComparison(Card card1) {
      assertFalse(card1.equals(null));
   }

   private void assertConsistency(Card card1, Card card1copy, Card card2) {
      assertTrue(card1.equals(card1copy));
      assertFalse(card1.equals(card2));
   }

   private void assertTransitivity(Card card1, Card card1copy, Card card1copy2) {
      assertTrue(card1copy.equals(card1copy2));
      assertTrue(card1.equals(card1copy2));
   }

   private void assertSymmetry(Card card1, Card card1copy) {
      assertTrue(card1.equals(card1copy));
      assertTrue(card1copy.equals(card1));
   }

   private void assertReflexivity(Card card1) {
      assertTrue(card1.equals(card1));
   }
}
